package com.bonus.canteen.core.health.mapper;

import java.util.List;
import com.bonus.canteen.core.health.domain.HealthChronic;

/**
 * 慢性病Mapper接口
 *
 * @author xsheng
 * @date 2025-05-25
 */
public interface HealthChronicMapper {
    /**
     * 查询慢性病
     *
     * @param chronicId 慢性病主键
     * @return 慢性病
     */
    public HealthChronic selectHealthChronicByChronicId(Long chronicId);

    /**
     * 查询慢性病列表
     *
     * @param healthChronic 慢性病
     * @return 慢性病集合
     */
    public List<HealthChronic> selectHealthChronicList(HealthChronic healthChronic);

    /**
     * 新增慢性病
     *
     * @param healthChronic 慢性病
     * @return 结果
     */
    public int insertHealthChronic(HealthChronic healthChronic);

    /**
     * 修改慢性病
     *
     * @param healthChronic 慢性病
     * @return 结果
     */
    public int updateHealthChronic(HealthChronic healthChronic);

    /**
     * 删除慢性病
     *
     * @param chronicId 慢性病主键
     * @return 结果
     */
    public int deleteHealthChronicByChronicId(Long chronicId);

    /**
     * 批量删除慢性病
     *
     * @param chronicIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHealthChronicByChronicIds(Long[] chronicIds);

}
