package com.bonus.canteen.core.health.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.health.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.health.domain.HealthChronic;
import com.bonus.canteen.core.health.service.IHealthChronicService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 慢性病Controller
 *
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "慢性病接口")
@RestController
@RequestMapping("/health_chronic")
public class HealthChronicController extends BaseController {
    @Autowired
    private IHealthChronicService healthChronicService;

    /**
     * 查询慢性病列表
     */
    @ApiOperation(value = "查询慢性病列表")
    //@RequiresPermissions("health:chronic:list")
    @GetMapping("/list")
    public TableDataInfo list(HealthChronic healthChronic) {
        startPage();
        List<HealthChronic> list = healthChronicService.selectHealthChronicList(healthChronic);
        return getDataTable(list);
    }

    /**
     * 导出慢性病列表
     */
    @ApiOperation(value = "导出慢性病列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:chronic:export")
    @SysLog(title = "慢性病", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出慢性病")
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthChronic healthChronic) {
        List<HealthChronic> list = healthChronicService.selectHealthChronicList(healthChronic);
        ExcelUtil<HealthChronic> util = new ExcelUtil<HealthChronic>(HealthChronic.class);
        util.exportExcel(response, list, "慢性病数据");
    }

    /**
     * 获取慢性病详细信息
     */
    @ApiOperation(value = "获取慢性病详细信息")
    //@RequiresPermissions("health:chronic:query")
    @GetMapping(value = "/{chronicId}")
    public AjaxResult getInfo(@PathVariable("chronicId") Long chronicId) {
        return success(healthChronicService.selectHealthChronicByChronicId(chronicId));
    }

    /**
     * 新增慢性病
     */
    @ApiOperation(value = "新增慢性病")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:chronic:add")
    @SysLog(title = "慢性病", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增慢性病")
    @PostMapping
    public AjaxResult add(@RequestBody HealthChronic healthChronic) {
        try {
            return toAjax(healthChronicService.insertHealthChronic(healthChronic));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改慢性病
     */
    @ApiOperation(value = "修改慢性病")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:chronic:edit")
    @SysLog(title = "慢性病", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改慢性病")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody HealthChronic healthChronic) {
        try {
            return toAjax(healthChronicService.updateHealthChronic(healthChronic));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除慢性病
     */
    @ApiOperation(value = "删除慢性病")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:chronic:remove")
    @SysLog(title = "慢性病", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除慢性病")
	@PostMapping("/del/{chronicIds}")
    public AjaxResult remove(@PathVariable Long[] chronicIds) {
        return toAjax(healthChronicService.deleteHealthChronicByChronicIds(chronicIds));
    }

    @ApiOperation("获取慢性病字典")
    @PostMapping({"/dict-health-chronic"})
    public AjaxResult dictHealthChronic(@RequestBody HealthChronic dto) {
        List<HealthChronic> list = this.healthChronicService.dictHealthChronic(dto);
        return AjaxResult.success(list);
    }
}
